frame.ds: Construct a Frame From a Difference Set

Description Usage Arguments Examples

View source: R/frm_fns.R

Description

Builds the character table from the given group and extracts the rows associated with the given difference set.

Usage

1

Arguments

ds

a difference set object constructed via build.ds function

Examples

1
frame.ds(diff.set.object)

HarmonicAnova21/FRame.BuildR documentation built on March 23, 2020, 5:17 a.m.