Description Usage Arguments Examples
Takes a vector of n integers and determines if it is a cyclic integer group of order n (or scalar - integer - multiple).
1 | is.group(g)
|
g |
a vector of integers |
1 | is.group(g = as.integer(0:5))
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.