Description Usage Arguments Examples
Builds the character table from the given group and extracts the rows associated with the given difference set.
1 | frame.ds(ds)
|
ds |
a difference set object constructed via build.ds function |
1 | frame.ds(diff.set.object)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.